@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.117_04';
+our $VERSION = '0.118_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Mon Mar 18 13:44:02 2019 GMT
+# on Fri Mar 22 14:58:34 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1739,7 +1739,7 @@ __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-0
 __PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
-__PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
+__PACKAGE__->status( add => 25272, iridium => '-', 'Iridium 55', 'Tumbling' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
 __PACKAGE__->status( add => 25274, iridium => 'S', 'Iridium 58', '' );
 __PACKAGE__->status( add => 25275, iridium => 'D', 'Iridium 59', 'Decayed 2019-03-11' );
@@ -1777,15 +1777,15 @@ __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-0
 __PACKAGE__->status( add => 27372, iridium => 'D', 'Iridium 91', 'Decayed 2019-03-13' );
 __PACKAGE__->status( add => 27373, iridium => 'D', 'Iridium 90', 'Decayed 2019-01-23' );
 __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-04-18' );
-__PACKAGE__->status( add => 27375, iridium => 'S', 'Iridium 95', '' );
+__PACKAGE__->status( add => 27375, iridium => '-', 'Iridium 95', 'Tumbling' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
 __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
 # Operational [+]: 2
-#       Spare [S]: 6
-#    Tumbling [-]: 32
+#       Spare [S]: 4
+#    Tumbling [-]: 34
 #     Decayed [D]: 57
 
 1;
